==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/GetEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Optional[Boolean] = Optional.Absent,
    sseType: Optional[zio.aws.ec2.model.SSEType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse = {
    import GetEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .optionallyWith(sseType.map(value => value.unwrap))(_.sseType)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.wrap(buildAwsValue())
}
object GetEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value),
        sseType.map(value => value)
      )
    def ebsEncryptionByDefault: Optional[Boolean]
    def sseType: Optional[zio.aws.ec2.model.SSEType]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
    def getSseType: ZIO[Any, AwsError, zio.aws.ec2.model.SSEType] =
      AwsError.unwrapOptionField("sseType", sseType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ebsEncryptionByDefault())
        .map(value => value: Boolean)
    override val sseType: Optional[zio.aws.ec2.model.SSEType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sseType())
        .map(value => zio.aws.ec2.model.SSEType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.17.126.1-sources.jar: zio/aws/ec2/model/GetEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse = {
    import GetEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.wrap(buildAwsValue())
}
object GetEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value)
      )
    def ebsEncryptionByDefault: Option[Boolean]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Option[Boolean] =
      scala.Option(impl.ebsEncryptionByDefault()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.GetEbsEncryptionByDefaultResponse.ReadOnly = new Wrapper(
    impl
  )
}
